////////////////////////////////////////////////////////////////////////////////
//     
//    __                                ______
//   / /_______________  ____  ___     / ____/
//  / __/ ___/ ___/ __ \/ __ \/ _ \   /___ )  
// / /_(__  ) /__/ /_/ / /_/ /  __/  ____/ /  
// \__/____/\___/\____/ .___/\___/  /_____/   
//                   /_/                      
//     
/// \file video_internal.c
/// Definitions of internal video functions.
////////////////////////////////////////////////////////////////////////////////


#include "../include/tscope5/video_internal.h"
#include "../include/tscope5/system_internal.h"
#include "../include/tscope5/audio_internal.h"

#include <allegro5/allegro_video.h>

/// Is the video subsystem installed?
int _ts5_is_video_installed = 0;


////////////////////////////////////////////////////////////////////////////////
/// Do some checks at the start of each video function.
///
/// \param calling_function Name the function that calls for 
/// this check or installation.
///
/// Checks whether the video subsystem is installed. 
/// If not, the video subsystem is installed.
////////////////////////////////////////////////////////////////////////////////
void ts5_check_video(char *calling_function)
{
	ts5_log(TS5_LOGLEVEL_6, "%s: ts5_check_video\n", calling_function);
	if (!_ts5_is_video_installed) {
		ts5_install_video(calling_function);
	}
}


////////////////////////////////////////////////////////////////////////////////
/// Install the video subsystem.
///
/// \param calling_function Name the function that calls for 
/// this check or installation.
///
/// This function is called automatically if necessary.
////////////////////////////////////////////////////////////////////////////////
void ts5_install_video(char *calling_function)
{
	if (!_ts5_is_tscope5_installed) {
		ts5_install_tscope5(calling_function);
	}
	
	if (!_ts5_is_audio_installed) {
		ts5_install_audio(calling_function);
	}

	if (!_ts5_is_video_installed) {

		_ts5_is_video_installed = 1;
		ts5_log(TS5_LOGLEVEL_1, "%s: Installing Tscope5 video\n", 
				calling_function);
		
		if (!al_init_video_addon()) {
			ts5_fatal("%s: could not install Tscope5 video\n", 
					calling_function);
		}
				
		atexit(ts5_uninstall_video);
	}
}


////////////////////////////////////////////////////////////////////////////////
/// Uninstall the video subsystem.
///
/// This function is called automatically at the end of the program.
////////////////////////////////////////////////////////////////////////////////
void ts5_uninstall_video()
{
	if (_ts5_is_video_installed) {

		ts5_log(TS5_LOGLEVEL_1, "Uninstalling Tscope5 video\n");

		al_shutdown_video_addon();
		
		_ts5_is_video_installed = 0;
	}
}
